@@ -45,6 +45,7 @@
 #include <KConfigSkeleton>
 #include <KXMLGUIFactory>
 
+#include <QApplication>
 #include <QDebug>
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
@@ -256,6 +257,18 @@ void MainWindow::setShowExtractDialog(bool option)
     }
 }
 
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+    // Preview windows don't have a parent, so we need to manually close them.
+    foreach (QWidget *widget, qApp->topLevelWidgets()) {
+        if (widget->isVisible()) {
+            widget->close();
+        }
+    }
+
+    KParts::MainWindow::closeEvent(event);
+}
+
 void MainWindow::quit()
 {
     close();
