@@ -354,28 +354,14 @@ bool CliInterface::deleteFiles(const QList<QVariant> & files)
     cacheParameterList();
     m_operationMode = Delete;
 
-    //start preparing the argument list
-    QStringList args = m_param.value(DeleteArgs).toStringList();
-
-    //now replace the various elements in the list
-    for (int i = 0; i < args.size(); ++i) {
-        QString argument = args.at(i);
-        qCDebug(ARK) << "Processing argument " << argument;
-
-        if (argument == QLatin1String( "$Archive" )) {
-            args[i] = filename();
-        } else if (argument == QLatin1String( "$Files" )) {
-            args.removeAt(i);
-            for (int j = 0; j < files.count(); ++j) {
-                args.insert(i + j, escapeFileName(files.at(j).toString()));
-                ++i;
-            }
-            --i;
-        }
-    }
-
     m_removedFiles = files;
 
+    const auto deleteArgs = m_param.value(DeleteArgs).toStringList();
+
+    const auto args = substituteDeleteVariables(deleteArgs,
+                                                files,
+                                                password());
+
     if (!runProcess(m_param.value(DeleteProgram).toStringList(), args)) {
         failOperation();
         return false;
@@ -684,6 +670,41 @@ QStringList CliInterface::substituteCopyVariables(const QStringList &extractArgs
     return args;
 }
 
+QStringList CliInterface::substituteDeleteVariables(const QStringList &deleteArgs, const QVariantList &files, const QString &password)
+{
+    cacheParameterList();
+
+    QStringList args;
+    foreach (const QString& arg, deleteArgs) {
+        qCDebug(ARK) << "Processing argument" << arg;
+
+        if (arg == QLatin1String("$Archive")) {
+            args << filename();
+            continue;
+        }
+
+        if (arg == QLatin1String("$PasswordSwitch")) {
+            args << passwordSwitch(password);
+            continue;
+        }
+
+        if (arg == QLatin1String("$Files")) {
+            foreach (const QVariant& file, files) {
+                args << escapeFileName(file.toString());
+            }
+            continue;
+        }
+
+        // Simple argument (e.g. d in rar), nothing to substitute, just add it to the list.
+        args << arg;
+    }
+
+    // Remove empty strings, if any.
+    args.removeAll(QString());
+
+    return args;
+}
+
 QString CliInterface::preservePathSwitch(bool preservePaths) const
 {
     Q_ASSERT(m_param.contains(PreservePathSwitch));
